==> haskell-conduit-parse-0.2.1.1-265-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 conduit-parse
version:              0.2.1.1
visibility:           public
id:                   conduit-parse-0.2.1.1-3c9WRS8QuZfHJHCsY0hwsk
key:                  conduit-parse-0.2.1.1-3c9WRS8QuZfHJHCsY0hwsk
license:              LicenseRef-PublicDomain
maintainer:           koral <koral@mailoo.org>
author:               koral <koral@mailoo.org>
homepage:             https://github.com/k0ral/conduit-parse
synopsis:             Parsing framework based on conduit.
description:          Please refer to README.
category:             Conduit, Text
abi:                  ac474964571649776680b247074c46bd
exposed:              True
exposed-modules:      Data.Conduit.Parser
hidden-modules:       Data.Conduit.Parser.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/conduit-parse-0.2.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/conduit-parse-0.2.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/conduit-parse-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit-parse
hs-libraries:         HSconduit-parse-0.2.1.1-3c9WRS8QuZfHJHCsY0hwsk
depends:
    base-4.17.2.1 conduit-1.3.6.1-6jCM8OP1Acj1IIa26Jdl9d
    dlist-1.0-BKgPi70fx5AJreCYiKxIIN mtl-2.2.2
    parsers-0.12.12-BBCj7Bb5jk88ztzRJGKsZL
    safe-0.3.21-8UNW4gIoNRmKgGFufdPOla
    safe-exceptions-0.1.7.4-2Rld96PQeHNLphPII72qvg text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-conduit-parse/html/conduit-parse.haddock

haddock-html:         /usr/share/doc/haskell-conduit-parse/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-parse-0.2.1.1-266-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 conduit-parse
version:              0.2.1.1
visibility:           public
id:                   conduit-parse-0.2.1.1-GdRAG6kQUMSL7PJptWzAIo
key:                  conduit-parse-0.2.1.1-GdRAG6kQUMSL7PJptWzAIo
license:              LicenseRef-PublicDomain
maintainer:           koral <koral@mailoo.org>
author:               koral <koral@mailoo.org>
homepage:             https://github.com/k0ral/conduit-parse
synopsis:             Parsing framework based on conduit.
description:          Please refer to README.
category:             Conduit, Text
abi:                  662c143165ab80c4aa3147b86dc8ed2e
exposed:              True
exposed-modules:      Data.Conduit.Parser
hidden-modules:       Data.Conduit.Parser.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/conduit-parse-0.2.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/conduit-parse-0.2.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/conduit-parse-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit-parse
hs-libraries:         HSconduit-parse-0.2.1.1-GdRAG6kQUMSL7PJptWzAIo
depends:
    base-4.17.2.1 conduit-1.3.6.1-83ARrK7GmQf2qu3DMBdhJp
    dlist-1.0-BKgPi70fx5AJreCYiKxIIN mtl-2.2.2
    parsers-0.12.12-otW7EfV3VJ68kSOSvXH7p
    safe-0.3.21-29OHNU5kqwB6czdAzMhG9H
    safe-exceptions-0.1.7.4-2FJBdfOuy5GJXMppmu6xCS text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-conduit-parse/html/conduit-parse.haddock

haddock-html:         /usr/share/doc/haskell-conduit-parse/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
